@@ -1,29 +1,13 @@
 use super::Value;
 use crate::output::Formatted;
-use crate::value::{ListSeparator, Operator, Quotes};
+use crate::value::{ListSeparator, Operator};
 use std::fmt::{self, Display, Write};
 
 impl<'a> Display for Formatted<'a, Value> {
     fn fmt(&self, out: &mut fmt::Formatter) -> fmt::Result {
         match *self.value {
             Value::Bang(ref s) => write!(out, "!{}", s),
-            Value::Literal(ref s, ref q) => match *q {
-                Quotes::None => write!(out, "{}", s),
-                Quotes::Double => {
-                    if s.contains('"') && !s.contains('\'') {
-                        write_sq(out, s)
-                    } else {
-                        write_dq(out, s)
-                    }
-                }
-                Quotes::Single => {
-                    if !s.contains('"') || s.contains('\'') {
-                        write_dq(out, s)
-                    } else {
-                        write_sq(out, s)
-                    }
-                }
-            },
+            Value::Literal(ref s) => s.fmt(out),
             Value::Function(ref n, ref _f) => {
                 let name = n
                     .chars()
@@ -91,7 +75,9 @@ impl<'a> Display for Formatted<'a, Value> {
             Value::Call(ref name, ref arg) => {
                 write!(out, "{}({})", name, arg)
             }
-            Value::BinOp(ref a, _, Operator::Plus, _, ref b) => {
+            Value::BinOp(ref a, _, Operator::Plus, _, ref b)
+                if a.type_name() != "number" || b.type_name() != "number" =>
+            {
                 // The plus operator is also a concat operator
                 a.format(self.format).fmt(out)?;
                 b.format(self.format).fmt(out)
@@ -158,39 +144,20 @@ impl<'a> Display for Formatted<'a, Value> {
                 out.write_char(')')
             }
             Value::ArgList(ref args) => {
-                let pos = args
-                    .positional
-                    .iter()
-                    .map(|v| format!("{}", v.format(self.format)));
-                let named = args.named.iter().map(|(k, v)| {
-                    format!("${}: {}", k, v.format(self.format))
-                });
-                let t = pos.chain(named).collect::<Vec<_>>().join(
-                    ListSeparator::Comma.sep(self.format.is_compressed()),
-                );
-                write!(out, "{}", t)
+                // Note: named args not included in output.
+                if let Some((first, rest)) = args.positional.split_first() {
+                    first.format(self.format).fmt(out)?;
+                    let sep =
+                        ListSeparator::Comma.sep(self.format.is_compressed());
+                    for item in rest {
+                        out.write_str(sep)?;
+                        item.format(self.format).fmt(out)?;
+                    }
+                } else {
+                    out.write_str("()")?;
+                }
+                Ok(())
             }
         }
     }
 }
-
-fn write_dq(out: &mut fmt::Formatter, s: &str) -> fmt::Result {
-    out.write_char('"')?;
-    for c in s.chars() {
-        if c == '"' {
-            out.write_char('\\')?;
-        }
-        out.write_char(c)?;
-    }
-    out.write_char('"')
-}
-fn write_sq(out: &mut fmt::Formatter, s: &str) -> fmt::Result {
-    out.write_char('\'')?;
-    for c in s.chars() {
-        if c == '\'' {
-            out.write_char('\\')?;
-        }
-        out.write_char(c)?;
-    }
-    out.write_char('\'')
-}
