@@ -1,5 +1,5 @@
 use super::cssbuf::{CssBuf, CssHead};
-use crate::css::{BodyItem, Rule};
+use crate::css::{BodyItem, Rule, Selectors};
 use crate::error::Error;
 use crate::file_context::FileContext;
 use crate::parser::parse_imported_scss_file;
@@ -7,7 +7,6 @@ use crate::sass::{
     self, get_global_module, Expose, FormalArgs, Function, Item, Mixin, Name,
     UseAs,
 };
-use crate::selectors::Selectors;
 use crate::value::ValueRange;
 use crate::ScopeRef;
 use std::io::Write;
@@ -45,16 +44,17 @@ fn handle_item(
     let format = scope.get_format();
     match item {
         Item::Use(ref name, ref as_n, ref with) => {
-            let name = name.evaluate(scope.clone())?.0;
-            let module = if let Some(module) = get_global_module(&name) {
+            let name = name.evaluate(scope.clone())?;
+            let module = if let Some(module) = get_global_module(name.value())
+            {
                 if !with.is_empty() {
                     return Err(Error::error(
-                        "Built-in modules can\'t be configured",
+                        "Built-in modules can\'t be configured.",
                     ));
                 }
                 module
             } else if let Some((sub_context, path, mut file)) =
-                file_context.find_file_use(&name)?
+                file_context.find_file_use(name.value())?
             {
                 head.load_module(
                     &path,
@@ -73,7 +73,7 @@ fn handle_item(
                                 module.define(name.clone(), &value);
                             } else {
                                 return Err(Error::error(
-                                    "The same variable may only be configured once",
+                                    "The same variable may only be configured once.",
                                 ));
                             }
                         }
@@ -94,21 +94,22 @@ fn handle_item(
                         Ok(module)
                     })?
             } else {
-                return Err(Error::S(format!("Module {:?} not found", name)));
+                return Err(Error::S(format!("Module {} not found", name)));
             };
-            scope.do_use(module, &name, as_n, &Expose::All)?;
+            scope.do_use(module, name.value(), as_n, &Expose::All)?;
         }
         Item::Forward(ref name, ref as_n, ref expose, ref with) => {
-            let name = name.evaluate(scope.clone())?.0;
-            let module = if let Some(module) = get_global_module(&name) {
+            let name = name.evaluate(scope.clone())?;
+            let module = if let Some(module) = get_global_module(name.value())
+            {
                 if !with.is_empty() {
                     return Err(Error::error(
-                        "Built-in modules can\'t be configured",
+                        "Built-in modules can\'t be configured.",
                     ));
                 }
                 module
             } else if let Some((sub_context, path, mut file)) =
-                file_context.find_file_use(&name)?
+                file_context.find_file_use(name.value())?
             {
                 head.load_module(
                     &path,
@@ -127,7 +128,7 @@ fn handle_item(
                                 module.define(name.clone(), &value);
                             } else {
                                 return Err(Error::error(
-                                    "The same variable may only be configured once",
+                                    "The same variable may only be configured once.",
                                 ));
                             }
                         }
@@ -148,17 +149,17 @@ fn handle_item(
                         Ok(module)
                     })?
             } else {
-                return Err(Error::S(format!("Module {:?} not found", name)));
+                return Err(Error::S(format!("Module {} not found", name)));
             };
-            scope.forward().do_use(module, &name, as_n, expose)?;
+            scope.forward().do_use(module, name.value(), as_n, expose)?;
         }
         Item::Import(ref names, ref args, ref pos) => {
             let mut rule = rule;
             'name: for name in names {
                 if args.is_null() {
-                    let (x, _q) = name.evaluate(scope.clone())?;
+                    let x = name.evaluate(scope.clone())?;
                     if let Some((sub_context, path, mut file)) =
-                        file_context.find_file_import(&x)?
+                        file_context.find_file_import(x.value())?
                     {
                         let items = parse_imported_scss_file(
                             &mut file,
@@ -185,16 +186,16 @@ fn handle_item(
                         continue 'name;
                     }
                 }
-                if buf.is_root_level() {
-                    head.add_import(
-                        name.evaluate2(scope.clone())?,
-                        args.evaluate(scope.clone())?,
-                    )?;
+                let name = name.evaluate(scope.clone())?;
+                let args = args.evaluate(scope.clone())?;
+                if let Some(ref mut rule) =
+                    rule.as_deref_mut().filter(|r| !r.selectors.is_root())
+                {
+                    rule.add_import(name, args);
+                } else if buf.is_root_level() {
+                    head.add_import(name, args)?;
                 } else {
-                    buf.add_import(
-                        name.evaluate2(scope.clone())?,
-                        args.evaluate(scope.clone())?,
-                    )?;
+                    buf.add_import(name, args)?;
                 }
             }
         }
@@ -221,7 +222,8 @@ fn handle_item(
             ref body,
         } => {
             buf.do_separate();
-            write!(buf, "@{}", name)?;
+            let name = name.evaluate(scope.clone())?;
+            write!(buf, "@{}", name.value())?;
             let args = args.evaluate(scope.clone())?;
             if !args.is_null() {
                 write!(buf, " {}", args.format(format))?;
@@ -229,7 +231,7 @@ fn handle_item(
             if let Some(ref body) = *body {
                 buf.add_one(" {", "{");
                 let selectors = scope.get_selectors().clone();
-                let has_selectors = selectors != Selectors::root();
+                let has_selectors = !selectors.is_root();
                 let mut rule = Rule::new(selectors);
                 let mut sub = CssBuf::new_below(buf);
                 handle_body(
@@ -294,27 +296,33 @@ fn handle_item(
             ));
         }
 
-        Item::MixinDeclaration(ref name, ref args, ref body) => scope
-            .define_mixin(
+        Item::MixinDeclaration(ref name, ref args, ref body, ref pos) => {
+            scope.define_mixin(
                 name.into(),
                 Mixin {
                     args: args.clone(),
                     scope: scope.clone(),
                     body: body.clone(),
+                    pos: pos.clone(),
                 },
-            ),
-        Item::MixinCall(ref name, ref args, ref body) => {
+            )
+        }
+        Item::MixinCall(ref name, ref args, ref body, ref pos) => {
             let sel = scope.get_selectors().clone();
             if let Some(mixin) = scope.get_mixin(&name.into()) {
                 let subscope = mixin
                     .args
                     .eval(
-                        ScopeRef::sub_selectors(mixin.scope, sel),
+                        ScopeRef::sub_selectors(mixin.scope.clone(), sel),
                         args.evaluate(scope.clone())?,
                     )
                     .map_err(|e| match e {
                         sass::ArgsError::Eval(e) => e,
-                        ae => Error::S(ae.to_string()),
+                        ae => Error::BadCall(
+                            ae.to_string(),
+                            pos.in_call(name),
+                            Some(mixin.pos.clone()),
+                        ),
                     })?;
                 subscope.define_mixin(
                     Name::from_static("%%BODY%%"),
@@ -322,6 +330,8 @@ fn handle_item(
                         args: FormalArgs::none(),
                         scope,
                         body: body.clone().unwrap_or_else(Mixin::no_body),
+                        // TODO: Get a better pos?
+                        pos: pos.clone(),
                     },
                 );
                 handle_body(
@@ -331,12 +341,27 @@ fn handle_item(
                     buf,
                     subscope,
                     file_context,
-                )?;
+                )
+                .map_err(|e: Error| match e {
+                    Error::BadArguments(msg, decl) => {
+                        let pos = pos.in_call(name);
+                        Error::BadCall(msg, pos, Some(decl))
+                    }
+                    Error::AtError(msg, _pos) => {
+                        let msg = format!("Error: {}", msg);
+                        Error::BadCall(msg, pos.clone(), None)
+                    }
+                    e => {
+                        let pos = pos.in_call(name);
+                        Error::BadCall(e.to_string(), pos, None)
+                    }
+                })?;
             } else {
-                return Err(Error::S(format!(
-                    "Unknown mixin {}({:?})",
-                    name, args
-                )));
+                return Err(Error::BadCall(
+                    format!("Unknown mixin {}", name),
+                    pos.clone(),
+                    None,
+                ));
             }
         }
         Item::Content => {
@@ -364,7 +389,7 @@ fn handle_item(
             let mut rule = rule;
             let pushed = scope.store_local_values(names);
             for value in values.evaluate(scope.clone())?.iter_items() {
-                scope.define_multi(&names, &value);
+                scope.define_multi(names, &value);
                 handle_body(
                     body,
                     head,
@@ -423,11 +448,11 @@ fn handle_item(
         Item::Warn(ref value) => {
             eprintln!("WARNING: {}", value.evaluate(scope)?.format(format));
         }
-        Item::Error(ref value) => {
-            return Err(Error::S(format!(
-                "Error: {}",
-                value.evaluate(scope)?.format(format)
-            )));
+        Item::Error(ref value, ref pos) => {
+            return Err(Error::AtError(
+                value.evaluate(scope)?.format(format).to_string(),
+                pos.clone(),
+            ));
         }
 
         Item::Rule(ref selectors, ref body) => {
@@ -453,8 +478,8 @@ fn handle_item(
             if let Some(rule) = rule {
                 let v = value.evaluate(scope.clone())?;
                 if !v.is_null() {
-                    let (name, _q) = name.evaluate(scope)?;
-                    rule.push(BodyItem::Property(name, v));
+                    let name = name.evaluate(scope)?;
+                    rule.push(BodyItem::Property(name.value().into(), v));
                 }
             } else {
                 return Err(Error::S("Global property not allowed".into()));
@@ -463,9 +488,12 @@ fn handle_item(
         Item::NamespaceRule(ref name, ref value, ref body) => {
             if let Some(rule) = rule {
                 let value = value.evaluate(scope.clone())?;
-                let (name, _quotes) = name.evaluate(scope.clone())?;
+                let name = name.evaluate(scope.clone())?;
                 if !value.is_null() {
-                    rule.push(BodyItem::Property(name.clone(), value));
+                    rule.push(BodyItem::Property(
+                        name.value().to_string(),
+                        value,
+                    ));
                 }
                 let mut t = Rule::new(Selectors::root());
                 let mut sub = CssBuf::new(format);
@@ -479,9 +507,10 @@ fn handle_item(
                 )?;
                 for item in t.body {
                     rule.push(match item {
-                        BodyItem::Property(n, v) => {
-                            BodyItem::Property(format!("{}-{}", name, n), v)
-                        }
+                        BodyItem::Property(n, v) => BodyItem::Property(
+                            format!("{}-{}", name.value(), n),
+                            v,
+                        ),
                         c => c,
                     })
                 }
@@ -498,12 +527,11 @@ fn handle_item(
         }
         Item::Comment(ref c) => {
             if !format.is_compressed() {
+                let c = c.evaluate(scope)?;
                 if let Some(rule) = rule {
-                    let (c, _q) = c.evaluate(scope)?;
-                    rule.push(BodyItem::Comment(c));
+                    rule.push(BodyItem::Comment(c.value().into()));
                 } else {
                     buf.do_separate();
-                    let (c, _q) = c.evaluate(scope)?;
                     write!(buf, "/*{}*/", c)?;
                 }
             }
