@@ -1,7 +1,8 @@
 use super::channels::Channels;
 use super::{
-    bad_arg, check_alpha, check_pct_range, check_rational, get_checked,
-    get_color, get_opt_check, is_special, make_call, CheckedArg, FunctionMap,
+    bad_arg, check_alpha, check_pct, check_pct_range, check_rational,
+    get_checked, get_color, get_opt_check, is_not, is_special, make_call,
+    CheckedArg, FunctionMap,
 };
 use crate::css::{CallArgs, Value};
 use crate::output::Format;
@@ -37,10 +38,7 @@ pub fn register(f: &mut Scope) {
             )
         }
         v @ Value::Numeric(..) => Ok(make_call("grayscale", vec![v])),
-        v => Err(Error::BadArgument(
-            name!(color),
-            format!("{} is not a color", v.format(Format::introspect()))
-        )),
+        v => Err(is_not(&v, "a color")).named(name!(color)),
     });
 }
 
@@ -54,7 +52,7 @@ pub fn expose(m: &Scope, global: &mut FunctionMap) {
         (name!(lightness), name!(lightness)),
         (name!(saturation), name!(saturation)),
     ] {
-        global.insert(gname.clone(), m.get_lfunction(&lname));
+        global.insert(gname.clone(), m.get_lfunction(lname));
     }
     let mut f = Scope::builtin_module("sass:color");
     def!(f, adjust_hue(color, degrees), |s| {
@@ -98,7 +96,7 @@ pub fn expose(m: &Scope, global: &mut FunctionMap) {
                     .eval(s.clone(), args)
                     .map_err(|e| bad_arg(e, &name!(saturate), &a2))?;
                 let sat = s.get("amount")?;
-                check_pct_range(sat.clone()).named(name!(amount))?;
+                check_pct(sat.clone()).named(name!(amount))?;
                 Ok(make_call("saturate", vec![sat]))
             }
             Err(ae) => Err(bad_arg(ae, &name!(saturate), &a1)),
@@ -118,7 +116,7 @@ pub fn expose(m: &Scope, global: &mut FunctionMap) {
         (name!(lighten), name!(lighten)),
         (name!(saturate), name!(saturate)),
     ] {
-        global.insert(gname.clone(), f.get_lfunction(&lname));
+        global.insert(gname.clone(), f.get_lfunction(lname));
     }
 }
 
@@ -175,7 +173,7 @@ fn hsla_from_values(
     if is_special(&h) || is_special(&s) || is_special(&l) || is_special(&a) {
         Ok(make_call(fn_name.as_ref(), vec![h, s, l, a]))
     } else if l == Value::Null {
-        Err(Error::error("Missing argument $lightness"))
+        Err(Error::error("Missing argument $lightness."))
     } else {
         Ok(Hsla::new(
             check_rational(h).named(name!(hue))?,
