@@ -1,12 +1,12 @@
 use super::{
-    check, expected_to, get_checked, get_opt_check, CheckedArg, Error,
-    FunctionMap,
+    check, expected_to, get_checked, get_opt_check, is_not, is_special,
+    CheckedArg, Error, FunctionMap,
 };
 use crate::css::{CallArgs, Value};
 use crate::output::Format;
 use crate::parser::SourcePos;
 use crate::sass::{ArgsError, FormalArgs, Name};
-use crate::value::{Color, Number, Numeric, Quotes, Rational, Unit};
+use crate::value::{Color, Number, Numeric, Rational, Unit};
 use crate::Scope;
 use num_traits::{one, zero, Signed};
 mod channels;
@@ -64,9 +64,7 @@ fn get_color(s: &Scope, name: &'static str) -> Result<Color, Error> {
 fn check_color(v: Value) -> Result<Color, String> {
     match v {
         Value::Color(col, _) => Ok(col),
-        v => {
-            Err(format!("{} is not a color", v.format(Format::introspect())))
-        }
+        v => Err(is_not(&v, "a color")),
     }
 }
 
@@ -165,19 +163,6 @@ fn num2chan(v: &Numeric) -> Result<Rational, String> {
     }
 }
 
-fn is_special(v: &Value) -> bool {
-    match v {
-        Value::Call(..) => true,
-        Value::Literal(s, Quotes::None) if looks_like_call(s) => true,
-        Value::BinOp(..) => true,
-        _ => false,
-    }
-}
-
-fn looks_like_call(s: &str) -> bool {
-    s.contains('(') && s.ends_with(')')
-}
-
 fn make_call(name: &str, args: Vec<Value>) -> Value {
     Value::Call(
         name.into(),
