@@ -1,12 +1,11 @@
 use super::{
     check, expected_to, get_checked, get_numeric, get_opt_check, get_va_list,
-    Error, FunctionMap, Scope,
+    is_not, is_special, CheckedArg, Error, FunctionMap, Scope,
 };
-use crate::css::Value;
+use crate::css::{CallArgs, CssString, Value};
 use crate::output::Format;
 use crate::sass::Name;
 use crate::value::{Number, Numeric, Quotes, Rational, Unit, UnitSet};
-use rand::{thread_rng, Rng};
 use std::cmp::Ordering;
 use std::f64::consts::{E, PI};
 
@@ -97,7 +96,7 @@ pub fn create_module() -> Scope {
     {
         [Value::Numeric(v, _)] =>
             Ok(number(v.value.clone().abs(), v.unit.clone())),
-        [v] => Err(Error::bad_arg(name!(number), &v, "is not a number")),
+        [v] => Err(is_not(v, "a number")).named(name!(number)),
         v => {
             if let Some((first, rest)) = v.split_first() {
                 let first = as_numeric(first)?;
@@ -105,17 +104,17 @@ pub fn create_module() -> Scope {
                 let unit = first.unit.clone();
                 for (i, v) in rest.iter().enumerate() {
                     let num = as_numeric(v)?;
-                    let scaled = num.as_unitset(&unit).ok_or_else(|| {
-                        Error::BadArgument(
-                            format!("numbers[{}]", i + 2).into(),
-                            diff_units_msg(&num, &first, "numbers[1]".into()),
-                        )
-                    })?;
+                    let scaled = num
+                        .as_unitset(&unit)
+                        .ok_or_else(|| {
+                            diff_units_msg(&num, &first, "numbers[1]".into())
+                        })
+                        .named(format!("numbers[{}]", i + 2).into())?;
                     sum += f64::from(scaled).powi(2);
                 }
                 Ok(number(sum.sqrt(), unit))
             } else {
-                Err(Error::error("At least one argument must be passed"))
+                Err(Error::error("At least one argument must be passed."))
             }
         }
     });
@@ -191,7 +190,7 @@ pub fn create_module() -> Scope {
     def!(f, unit(number), |s| {
         let mut unit = get_numeric(s, "number")?.unit;
         unit.simplify();
-        Ok(Value::Literal(unit.to_string(), Quotes::Double))
+        Ok(CssString::new(unit.to_string(), Quotes::Double).into())
     });
 
     // - - - Other Functions - - -
@@ -205,7 +204,7 @@ pub fn create_module() -> Scope {
             if v > 0 {
                 Ok(v)
             } else {
-                Err(format!("Must be greater than 0, was {}", v))
+                Err(format!("Must be greater than 0, was {}.", v))
             }
         })? {
             None => {
@@ -241,7 +240,7 @@ pub fn expose(m: &Scope, global: &mut FunctionMap) {
         (name!(percentage), name!(percentage)),
         (name!(random), name!(random)),
     ] {
-        global.insert(gname.clone(), m.get_lfunction(&lname));
+        global.insert(gname.clone(), m.get_lfunction(lname));
     }
 }
 
@@ -274,17 +273,55 @@ fn deg_value(rad: f64) -> Value {
 }
 
 fn find_extreme(v: &[Value], pref: Ordering) -> Result<Value, Error> {
-    find_extreme_inner(v, pref)?
-        .ok_or_else(|| Error::error("At least one argument must be passed"))
-        .map(Into::into)
+    let as_call = || {
+        Value::Call(
+            if pref == Ordering::Greater {
+                "max"
+            } else {
+                "min"
+            }
+            .into(),
+            CallArgs::from_list(v.to_vec()),
+        )
+    };
+    if v.iter().any(is_special) {
+        return Ok(as_call());
+    }
+    match find_extreme_inner(v, pref) {
+        Ok(Some(v)) => Ok(v.into()),
+        Ok(None) => {
+            Err(Error::error("At least one argument must be passed."))
+        }
+        Err(ExtremeError::NonNumeric(v)) => {
+            if v.type_name() == "unknown" {
+                Ok(as_call())
+            } else {
+                Err(Error::error(is_not(&v, "a number")))
+            }
+        }
+        Err(ExtremeError::Incompatible(a, b)) => {
+            if a.unit.dimension().is_empty() || b.unit.dimension().is_empty()
+            {
+                Ok(as_call())
+            } else {
+                Err(Error::error(format!(
+                    "{} and {} have incompatible units.",
+                    a.format(Format::introspect()),
+                    b.format(Format::introspect()),
+                )))
+            }
+        }
+        Err(_) => Ok(as_call()),
+    }
 }
 
 fn find_extreme_inner(
     v: &[Value],
     pref: Ordering,
-) -> Result<Option<Numeric>, Error> {
+) -> Result<Option<Numeric>, ExtremeError> {
     if let Some((first, rest)) = v.split_first() {
-        let va = check::numeric(first.clone()).map_err(Error::error)?;
+        let va = check::numeric(first.clone())
+            .map_err(|_| ExtremeError::NonNumeric(first.clone()))?;
         if let Some(vb) = find_extreme_inner(rest, pref)? {
             if let Some(o) = va.partial_cmp(&vb) {
                 Ok(Some(if o == pref { va } else { vb }))
@@ -292,18 +329,10 @@ fn find_extreme_inner(
                 if let Some(o) = va.value.partial_cmp(&vb.value) {
                     Ok(Some(if o == pref { va } else { vb }))
                 } else {
-                    Err(Error::error(format!(
-                        "{} and {} could not be compared",
-                        va.format(Format::introspect()),
-                        vb.format(Format::introspect()),
-                    )))
+                    Err(ExtremeError::Incomparable(va, vb))
                 }
             } else {
-                Err(Error::error(format!(
-                    "{} and {} have incompatible units",
-                    va.format(Format::introspect()),
-                    vb.format(Format::introspect()),
-                )))
+                Err(ExtremeError::Incompatible(va, vb))
             }
         } else {
             Ok(Some(va))
@@ -313,8 +342,15 @@ fn find_extreme_inner(
     }
 }
 
+#[derive(Debug)]
+enum ExtremeError {
+    NonNumeric(Value),
+    Incompatible(Numeric, Numeric),
+    Incomparable(Numeric, Numeric),
+}
+
 fn intrand(lim: i64) -> i64 {
-    thread_rng().gen_range(0..lim)
+    fastrand::i64(0..lim)
 }
 
 fn diff_units_msg(
@@ -323,7 +359,7 @@ fn diff_units_msg(
     other_name: Name,
 ) -> String {
     format!(
-        "{} and ${}: {} have incompatible units{}",
+        "{} and ${}: {} have incompatible units{}.",
         one.format(Format::introspect()),
         other_name,
         other.format(Format::introspect()),
