@@ -1,6 +1,5 @@
-use super::{CallArgs, FormalArgs, Name, SassString, Value};
+use super::{CallArgs, FormalArgs, Name, SassString, Selectors, Value};
 use crate::parser::SourcePos;
-use crate::selectors::Selectors;
 use std::collections::BTreeSet;
 
 /// Every sass file is a sequence of sass items.
@@ -26,7 +25,7 @@ pub enum Item {
     /// A generic `@` directive.
     AtRule {
         /// The name of this directive
-        name: String,
+        name: SassString,
         /// Any arguments
         args: Value,
         /// The directive may have a body.
@@ -37,12 +36,12 @@ pub enum Item {
     /// An `@warn` directive.
     Warn(Value),
     /// An `@error` directive.
-    Error(Value),
+    Error(Value, SourcePos),
 
     /// A `@mixin` directive, declaring a mixin.
-    MixinDeclaration(String, FormalArgs, Vec<Item>),
+    MixinDeclaration(String, FormalArgs, Vec<Item>, SourcePos),
     /// An `@include` directive, calling a mixin.
-    MixinCall(String, CallArgs, Option<Vec<Item>>),
+    MixinCall(String, CallArgs, Option<Vec<Item>>, SourcePos),
     /// An `@content` directive (in a mixin declaration).
     Content,
 
