@@ -213,37 +213,6 @@ fn weight_parameter() {
     )
 }
 
-/// From `spec/core_functions/rgba/success`
-#[test]
-fn rgba_success() {
-    check(
-        b"a {\n  calc-1: rgba(calc(1), 2, 3, 0.4);\n  \
-          calc-2: rgba(1, calc(2), 3, 0.4);\n  \
-          calc-3: rgba(1, 2, calc(3), 0.4);\n  \
-          calc-4: rgba(1, 2, 3, calc(0.4));\n\n  \
-          var-1: rgba(var(--foo), 2, 3, 0.4);\n  \
-          var-2: rgba(1, var(--foo), 3, 0.4);\n  \
-          var-3: rgba(1, 2, var(--foo), 0.4);\n  \
-          var-4: rgba(1, 2, 3, var(0.4));\n\n  \
-          calc-2-args: rgba(blue, calc(0.4));\n  \
-          var-2-args-alpha: rgba(blue, var(0.4));\n  \
-          var-2-args-color: rgba(var(--foo), 0.4);\n  \
-          var-2-args-both: rgba(var(--foo), var(0.4));\n}\n",
-        "a {\n  calc-1: rgba(calc(1), 2, 3, 0.4);\n  \
-         calc-2: rgba(1, calc(2), 3, 0.4);\n  \
-         calc-3: rgba(1, 2, calc(3), 0.4);\n  \
-         calc-4: rgba(1, 2, 3, calc(0.4));\n  \
-         var-1: rgba(var(--foo), 2, 3, 0.4);\n  \
-         var-2: rgba(1, var(--foo), 3, 0.4);\n  \
-         var-3: rgba(1, 2, var(--foo), 0.4);\n  \
-         var-4: rgba(1, 2, 3, var(0.4));\n  \
-         calc-2-args: rgba(blue, calc(0.4));\n  \
-         var-2-args-alpha: rgba(blue, var(0.4));\n  \
-         var-2-args-color: rgba(var(--foo), 0.4);\n  \
-         var-2-args-both: rgba(var(--foo), var(0.4));\n}\n",
-    )
-}
-
 /// From `spec/libsass-closed-issues/issue_1133/normal`
 #[test]
 fn each_binds_multiple() {
@@ -360,6 +329,113 @@ fn test_rational_overflow_sub() {
     check_value("4142135623 - 1.4142135623", "4142135621.5857864377")
 }
 
+/// https://github.com/kaj/rsass/issues/116
+/// map.merge incorrect output for nested map
+#[test]
+fn issue_116() {
+    check(
+        b"@use \"sass:map\";\n\
+         \n$fonts: (\
+         \n  \"Helvetica\": (\
+         \n    \"weights\": (\
+         \n      \"regular\": 400,\
+         \n      \"medium\": 500,\
+         \n      \"bold\": 700\
+         \n    )\
+         \n  )\
+         \n);\n\
+         \na {\
+         \n    color: inspect(map.merge($fonts, \"Helvetica\", \"weights\", \"regular\", (a: 300)));\
+         \n}\n",
+        "a {\
+         \n  color: (\"Helvetica\": (\"weights\": (\"regular\": (a: 300), \"medium\": 500, \"bold\": 700)));\
+         \n}\n",
+    );
+}
+
+/// https://github.com/kaj/rsass/issues/122
+/// A division by zero that causes a panic
+mod issue_122 {
+    use super::check_value;
+    // Note: The important thing here is not to panic, the exact
+    // output may be changed in the future, maybe to report an error.
+    #[test]
+    fn reduced() {
+        check_value("(#111 + #aaa)/0", "#bbbbbb/0")
+    }
+    #[test]
+    fn reported() {
+        check_value(
+            "54A444/0+-4444M4#444/-4444/0+-4444M4#444+44/0+444/0+.44444O#444+44/0+4/46",
+            "InfinityA444+-4444M4 black/0-4444M4 #444InfinityInfinity0.44444O #444Infinity0.0869565217",
+        )
+    }
+    /// https://github.com/kaj/rsass/issues/121 is very similar.
+    #[test]
+    fn issue_121() {
+        check_value(
+            "44A-#444/0+-\0\0\0+44/0+444&",
+            "44A-#444/0-\u{1}\u{0}\u{0}\u{0}Infinity444",
+        )
+    }
+}
+
+/// Overflow in gcd for subtraction.
+#[test]
+fn issue_120() {
+    check_value(
+        "4444#4444-.4555555555555555555555555",
+        "4444 rgba(68, 68, 68, 0.2666666667)",
+    )
+}
+
+/// Test auto-converted from "sass-spec/spec/libsass/rel.hrx", except one failing unit calculation.
+#[test]
+fn rel() {
+    check(
+        b"div {\
+          \n  less: 3px < 3pt;\
+          \n  less: (1px / 1pt);\
+          \n  less: 23fu < 120;\
+          \n  eq: hello == hello;\
+          \n  eq: \"hello\" == hello;\
+          \n  eq: (1 2 3) == (1 2 3);\
+          \n  eq: (1 2 3) == (1, 2, 3);\
+          \n  eq: 23px == 23fu;\
+          \n  eq: 3.1in == 2.54cm;\
+          \n  eq: 2.54cm == 3.1in;\
+          \n  eq: (1in) == (1cm*1in/1cm);\
+          \n  x: 1in, (1cm*1in/1cm);\
+          \n  eq: (2cm*1in/2cm) == (1in*2cm/2cm);\
+          \n  blah: (1cm/1in);\
+          \n  in: (1in*2.54cm/1in);\
+          \n  lt: 1in < 2.54cm;\
+          \n  lt: 2.54cm < 1in;\
+          \n  lt: 5 < 4;\
+          \n}\n",
+        "div {\
+         \n  less: true;\
+         \n  less: 0.75;\
+         \n  less: true;\
+         \n  eq: true;\
+         \n  eq: true;\
+         \n  eq: true;\
+         \n  eq: false;\
+         \n  eq: false;\
+         \n  eq: false;\
+         \n  eq: false;\
+         \n  eq: true;\
+         \n  x: 1in, 1in;\
+         \n  eq: true;\
+         \n  blah: 0.3937007874;\
+         \n  in: 2.54cm;\
+         \n  lt: false;\
+         \n  lt: false;\
+         \n  lt: false;\
+         \n}\n",
+    );
+}
+
 fn check_value(input: &str, expected: &str) {
     assert_eq!(
         String::from_utf8(
